#
# spec file for package python-numpydoc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-numpydoc
Version:        0.7.0
Release:        lp151.2.2
Summary:        Sphinx extension to support docstrings in Numpy format
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/numpy/numpydoc
Source:         https://files.pythonhosted.org/packages/source/n/numpydoc/numpydoc-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 2.7.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with tests}
BuildRequires:  %{python_module Sphinx >= 1.0.1}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module nose}
%endif
Requires:       python-Sphinx >= 1.0.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Numpy's documentation uses several custom extensions to Sphinx.  These
are shipped in this numpydoc package, in case you want to make use
of them in third-party projects.

%prep
%setup -q -n numpydoc-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
%python_exec setup.py -q test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE.txt README.rst
%{python_sitelib}/numpydoc/
%{python_sitelib}/numpydoc-%{version}-py*.egg-info

%changelog
* Sat Sep 30 2017 arun@gmx.de
- update to version 0.7.0:
  * make tests run under python2.7
  * less hacky solution to duplicate section error message, added
    tests
  * make getting filename python2 compatible
  * add context to signature mangling errors
  * MAINT: set version number to 0.7.0.dev0
  * Fix regression in #81
  * BUG: Make docscrape ParseError Python 3 compatible.
  * TST: update test for change in gh-81.
  * MAINT: set minimum Sphinx version to 1.2.3, remove linkcode
    extension.
  * TST: run tests on TravisCI with Python 3.6 instead of 3.5
  * TST: run test suite after installing via sdist.
  * BUG: fix installing numydoc, broken with missing templates after
    gh-77.
  * Added ..currentmodule:: before ..autosummary::
  * Add dependency on jinja2
  * MAINT: add PyPI classifier for Python 3.6, remove Python 2.6 / 3.3
  * Render numpydoc strings from a template
  * Add __version__ attribute
  * ENH: use __text_signature__ if pydoc.doc does not reveal a
    signature.
  * Remove non Python3 compatible files
  * add (possibly slightly off) source lines to mangled docstrings.
  * FIX Unknow sections should not raise an error
  * MAINT Added *.swp and *.swo to gitignore
  * FIX raises an error if a section appears twice
  * adjust tests
  * bold attributes so we don't have to deal with trailing
    underscores. Also looks better.
  * BLD: fix sphinx version req
  * Use setuptools 'install_requires' instead of 'requires' in
    setup.py.
  * change to deep copy for doc sections.
  * allow extending NumpyDocString sections
  * Make default citation pattern more general
  * Make citation pattern configurable
  * Avoid sorting references by length while renaming
  * Factor out function to rename references
* Wed May 17 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Fix source URL.
* Fri Jan 20 2017 toddrme2178@gmail.com
- update to version 0.6.0:
  * REL: use the distutils sdist command instead of the setuptools
    one.
  * numpydoc.docscrape: Restore support for Python 3.4.
  * CI: run Travis on Sphinx 1.2.x and latest
  * better error messages from NumpyDocString
  * MAINT inspect.getfullargspec is deprecated in Py3.5
  * return extension metadata
  * CI: fix travis pip install + add caching
  * BUG: fix spacing in sphinx class doc attribute listing
  * PEP8 fixes for docscrape_sphinx.py
  * PEP8 fixes for docscrape.py
  * PEP8 fixes for numpydoc.py
  * MAINT: More explicit call while building docstrings.
  * TST: More unit tests for the Yields section.
  * ENH: Raise exception if docstring contains Returns and Yields.
  * TST : removed print statement
  * ENH : simplify handling of Yield section
  * Add support for Yields for sphinx strings as well.
  * Add unit test for Yields section.
  * ENH : NumpyDocString subclass collections.Mapping
  * Support Yields section in traitsdoc too.
  * Support Yields section.
* Thu May  7 2015 benoit.monin@gmx.fr
- update to version 0.5:
  * no changelog available
- update project URL
- add python-matplotlib and python-nose as test requirements
- remove all update-alternatives logic since autosummary_generate
  is not provided anymore
- pass -q to test to avoid spamming the build log
- rename README.txt to README.rst: changed upstream
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Oct 31 2013 toddrme2178@gmail.com
- Implement update-alternatives
* Thu Aug 15 2013 speilicke@suse.com
- Rename spec / changes file to project name
* Mon Aug 12 2013 speilicke@suse.com
- Initial version
